# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.invite_token_generate_request import InviteTokenGenerateRequest

class TestInviteTokenGenerateRequest(unittest.TestCase):
    """InviteTokenGenerateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteTokenGenerateRequest:
        """Test InviteTokenGenerateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteTokenGenerateRequest`
        """
        model = InviteTokenGenerateRequest()
        if include_optional:
            return InviteTokenGenerateRequest(
                invite_tokens = [
                    ''
                    ]
            )
        else:
            return InviteTokenGenerateRequest(
        )
        """

    def testInviteTokenGenerateRequest(self):
        """Test InviteTokenGenerateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
