# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.share_http_healthcheck_request import ShareHttpHealthcheckRequest

class TestShareHttpHealthcheckRequest(unittest.TestCase):
    """ShareHttpHealthcheckRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ShareHttpHealthcheckRequest:
        """Test ShareHttpHealthcheckRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ShareHttpHealthcheckRequest`
        """
        model = ShareHttpHealthcheckRequest()
        if include_optional:
            return ShareHttpHealthcheckRequest(
                env_zid = '',
                share_token = '',
                http_verb = '',
                endpoint = '',
                expected_http_response = 1.337,
                timeout_ms = 1.337
            )
        else:
            return ShareHttpHealthcheckRequest(
        )
        """

    def testShareHttpHealthcheckRequest(self):
        """Test ShareHttpHealthcheckRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
