# coding: utf-8

"""
    zrok

    zrok client access

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from zrok_api.models.remote_access_request import RemoteAccessRequest

class TestRemoteAccessRequest(unittest.TestCase):
    """RemoteAccessRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RemoteAccessRequest:
        """Test RemoteAccessRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RemoteAccessRequest`
        """
        model = RemoteAccessRequest()
        if include_optional:
            return RemoteAccessRequest(
                env_zid = '',
                token = '',
                bind_address = '',
                auto_mode = True,
                auto_address = '',
                auto_start_port = 1,
                auto_end_port = 1,
                response_headers = [
                    ''
                    ]
            )
        else:
            return RemoteAccessRequest(
        )
        """

    def testRemoteAccessRequest(self):
        """Test RemoteAccessRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
